import sqlite3
import csv
import json
import hashlib

from structlog import get_logger

log = get_logger()


class Beaker:
    def __init__(self, table_name: str):
        self.table_name = table_name

    def __repr__(self):
        return f"Beaker({self.table_name})"

    def __iter__(self):
        self.cursor.execute(f"SELECT data FROM {self.table_name}")
        data = self.cursor.fetchall()
        for item in data:
            yield item["id"], item["data"]

    def __len__(self):
        self.cursor.execute(f"SELECT COUNT(*) FROM {self.table_name}")
        return self.cursor.fetchone()[0]

    def connect_to_db(self, db) -> None:
        self.db = db
        self.cursor = self.db.cursor()
        self.cursor.row_factory = sqlite3.Row
        # create table if it doesn't exist
        self.cursor.execute(
            f"CREATE TABLE IF NOT EXISTS {self.table_name} (id INTEGER PRIMARY KEY, data JSON, from_table TEXT NULL, from_id INTEGER NULL)"
        )

    def add_item(self, item: dict, from_table=None, from_id=None) -> None:
        self.cursor.execute(
            f"INSERT INTO {self.table_name} (data) VALUES (?)", (json.dumps(item),)
        )
        self.db.commit()
